==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/fluentd/FluentdFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.fluentd;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.constraints.NotNull;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class FluentdFluentImpl<A extends FluentdFluent<A>> extends BaseFluent<A> implements FluentdFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private FluentdSpecBuilder spec;

    public FluentdFluentImpl(){
    }
    public FluentdFluentImpl(Fluentd instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public FluentdFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public FluentdFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public FluentdFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public FluentdFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public FluentdFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public FluentdSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public FluentdSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(FluentdSpec spec){
            _visitables.remove(this.spec);
            if (spec!=null){ this.spec= new FluentdSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public A withNewSpec(String address,Boolean integerDuration){
            return (A)withSpec(new FluentdSpec(address, integerDuration));
    }

    public FluentdFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public FluentdFluent.SpecNested<A> withNewSpecLike(FluentdSpec item){
            return new SpecNestedImpl(item);
    }

    public FluentdFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public FluentdFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new FluentdSpecBuilder().build());
    }

    public FluentdFluent.SpecNested<A> editOrNewSpecLike(FluentdSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FluentdFluentImpl that = (FluentdFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<FluentdFluent.MetadataNested<N>> implements FluentdFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) FluentdFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends FluentdSpecFluentImpl<FluentdFluent.SpecNested<N>> implements FluentdFluent.SpecNested<N>,Nested<N>{

            private final FluentdSpecBuilder builder;
    
            SpecNestedImpl(FluentdSpec item){
                    this.builder = new FluentdSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new FluentdSpecBuilder(this);
            }
    
    public N and(){
            return (N) FluentdFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/fluentd/FluentdFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.fluentd;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class FluentdFluentImpl<A extends FluentdFluent<A>> extends BaseFluent<A> implements FluentdFluent<A>{

    private String apiVersion;
    private String kind;
    private ObjectMetaBuilder metadata;
    private FluentdSpecBuilder spec;

    public FluentdFluentImpl(){
    }
    public FluentdFluentImpl(Fluentd instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public FluentdFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public FluentdFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public FluentdFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public FluentdFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public FluentdFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public FluentdSpec getSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public FluentdSpec buildSpec(){
            return this.spec!=null?this.spec.build():null;
    }

    public A withSpec(FluentdSpec spec){
            _visitables.get("spec").remove(this.spec);
            if (spec!=null){ this.spec= new FluentdSpecBuilder(spec); _visitables.get("spec").add(this.spec);} return (A) this;
    }

    public Boolean hasSpec(){
            return this.spec != null;
    }

    public FluentdFluent.SpecNested<A> withNewSpec(){
            return new SpecNestedImpl();
    }

    public FluentdFluent.SpecNested<A> withNewSpecLike(FluentdSpec item){
            return new SpecNestedImpl(item);
    }

    public FluentdFluent.SpecNested<A> editSpec(){
            return withNewSpecLike(getSpec());
    }

    public FluentdFluent.SpecNested<A> editOrNewSpec(){
            return withNewSpecLike(getSpec() != null ? getSpec(): new FluentdSpecBuilder().build());
    }

    public FluentdFluent.SpecNested<A> editOrNewSpecLike(FluentdSpec item){
            return withNewSpecLike(getSpec() != null ? getSpec(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            FluentdFluentImpl that = (FluentdFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<FluentdFluent.MetadataNested<N>> implements FluentdFluent.MetadataNested<N>,Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) FluentdFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class SpecNestedImpl<N> extends FluentdSpecFluentImpl<FluentdFluent.SpecNested<N>> implements FluentdFluent.SpecNested<N>,Nested<N>{

            private final FluentdSpecBuilder builder;
    
            SpecNestedImpl(FluentdSpec item){
                    this.builder = new FluentdSpecBuilder(this, item);
            }
            SpecNestedImpl(){
                    this.builder = new FluentdSpecBuilder(this);
            }
    
    public N and(){
            return (N) FluentdFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec(){
            return and();
    }

}


}
